@@ -15,14 +15,13 @@
  * along with this program.  If not, see <http://www.gnu.org/licenses/>.
  */
 
-
 #include "abstract_fc_solve_solver.h"
 
 // own
 #include "patsolve-config.h"
 // freecell-solver
-#include "freecell-solver/fcs_user.h"
 #include "freecell-solver/fcs_cl.h"
+#include "freecell-solver/fcs_user.h"
 // St
 #include <cstdlib>
 #include <cstring>
@@ -52,7 +51,7 @@ const auto SOFT_SUSPEND = FCS_STATE_SUSPEND_PROCESS;
 #endif
 
 /* Get the possible moves from a position, and store them in Possible[]. */
-SolverInterface::ExitStatus FcSolveSolver::patsolve( int _max_positions )
+SolverInterface::ExitStatus FcSolveSolver::patsolve(int _max_positions)
 {
     int current_iters_count = 0;
     max_positions = (_max_positions < 0) ? default_max_positions : _max_positions;
@@ -60,11 +59,19 @@ SolverInterface::ExitStatus FcSolveSolver::patsolve( int _max_positions )
     init();
 
     // call free once the function ends. ### Replace this mess with QScopeGuard once we can use Qt 5.12
-    auto cleanup = [this](){this->free();};
-    using CleanupFunction = decltype (cleanup);
+    auto cleanup = [this]() {
+        this->free();
+    };
+    using CleanupFunction = decltype(cleanup);
     struct CleanupHandler {
-        CleanupHandler(CleanupFunction cleanup) : m_cleanup(std::move(cleanup)) {}
-        ~CleanupHandler() { m_cleanup();}
+        CleanupHandler(CleanupFunction cleanup)
+            : m_cleanup(std::move(cleanup))
+        {
+        }
+        ~CleanupHandler()
+        {
+            m_cleanup();
+        }
 
         CleanupFunction m_cleanup;
     } cleaner(cleanup);
@@ -72,10 +79,10 @@ SolverInterface::ExitStatus FcSolveSolver::patsolve( int _max_positions )
     int no_use = 0;
     int num_moves = 0;
     const auto get_possible_moves__ret = get_possible_moves(&no_use, &num_moves);
-    Q_ASSERT( num_moves == get_possible_moves__ret );
-    Q_ASSERT( m_firstMoves.isEmpty() );
+    Q_ASSERT(num_moves == get_possible_moves__ret);
+    Q_ASSERT(m_firstMoves.isEmpty());
     for (int j = 0; j < num_moves; ++j)
-        m_firstMoves.append( Possible[j] );
+        m_firstMoves.append(Possible[j]);
     // Sometimes the solver is invoked with a small maximal iterations
     // quota/limit (e.g: when loading a saved game or checking for autodrop
     // moves) and it is done frequently, so we return prematurely without
@@ -83,33 +90,29 @@ SolverInterface::ExitStatus FcSolveSolver::patsolve( int _max_positions )
     // overhead.
     //
     // The m_firstMoves should be good enough in that case.
-    if (max_positions < 20)
-    {
+    if (max_positions < 20) {
         return Solver::UnableToDetermineSolvability;
     }
-    if (!solver_instance)
-    {
+    if (!solver_instance) {
         {
             solver_instance = freecell_solver_user_alloc();
 
             solver_ret = FCS_STATE_NOT_BEGAN_YET;
 
-            char * error_string;
+            char *error_string;
             int error_arg;
-            const char * known_parameters[1] = {nullptr};
+            const char *known_parameters[1] = {nullptr};
             /*  A "char *" copy instead of "const char *". */
 
-            int parse_args_ret_code = freecell_solver_user_cmd_line_parse_args(
-                solver_instance,
-                get_cmd_line_arg_count() ,
-                get_cmd_line_args(),
-                0,
-                known_parameters,
-                nullptr,
-                nullptr,
-                &error_string,
-                &error_arg
-            );
+            int parse_args_ret_code = freecell_solver_user_cmd_line_parse_args(solver_instance,
+                                                                               get_cmd_line_arg_count(),
+                                                                               get_cmd_line_args(),
+                                                                               0,
+                                                                               known_parameters,
+                                                                               nullptr,
+                                                                               nullptr,
+                                                                               &error_string,
+                                                                               &error_arg);
 
             Q_ASSERT(!parse_args_ret_code);
         }
@@ -128,35 +131,20 @@ SolverInterface::ExitStatus FcSolveSolver::patsolve( int _max_positions )
 #endif
     }
 
-    if (solver_instance)
-    {
+    if (solver_instance) {
         bool continue_loop = true;
-        while (continue_loop &&
-                (   (solver_ret == FCS_STATE_NOT_BEGAN_YET)
-                 || (solver_ret == SOFT_SUSPEND))
-                    &&
-                 (current_iters_count < max_positions)
-              )
-        {
+        while (continue_loop && ((solver_ret == FCS_STATE_NOT_BEGAN_YET) || (solver_ret == SOFT_SUSPEND)) && (current_iters_count < max_positions)) {
             current_iters_count += CHUNKSIZE;
             set_soft_limit(solver_instance, current_iters_count);
 
-            if (solver_ret == FCS_STATE_NOT_BEGAN_YET)
-            {
-                solver_ret =
-                    freecell_solver_user_solve_board(
-                        solver_instance,
-                        board_as_string
-                    );
-            }
-            else
-            {
+            if (solver_ret == FCS_STATE_NOT_BEGAN_YET) {
+                solver_ret = freecell_solver_user_solve_board(solver_instance, board_as_string);
+            } else {
                 solver_ret = freecell_solver_user_resume_solution(solver_instance);
             }
             {
                 // QMutexLocker lock( &endMutex );
-                if ( m_shouldEnd )
-                {
+                if (m_shouldEnd) {
                     continue_loop = false;
                 }
             }
@@ -168,39 +156,35 @@ SolverInterface::ExitStatus FcSolveSolver::patsolve( int _max_positions )
     fprintf(stderr, "iters = %ld\n", reached_iters);
 #endif
 
-    switch (solver_ret)
-    {
-        case FCS_STATE_IS_NOT_SOLVEABLE:
-            make_solver_instance_ready();
-            return Solver::NoSolutionExists;
+    switch (solver_ret) {
+    case FCS_STATE_IS_NOT_SOLVEABLE:
+        make_solver_instance_ready();
+        return Solver::NoSolutionExists;
 
-        case FCS_STATE_WAS_SOLVED:
-            {
-                if (solver_instance)
-                {
-                    m_winMoves.clear();
-                    fcs_move_t move;
-                    while (!freecell_solver_user_get_next_move(solver_instance, &move))
-                    {
-                        MOVE new_move;
+    case FCS_STATE_WAS_SOLVED: {
+        if (solver_instance) {
+            m_winMoves.clear();
+            fcs_move_t move;
+            while (!freecell_solver_user_get_next_move(solver_instance, &move)) {
+                MOVE new_move;
 
-                        new_move.is_fcs = true;
-                        new_move.fcs = move;
+                new_move.is_fcs = true;
+                new_move.fcs = move;
 
-                        m_winMoves.append( new_move );
-                    }
-
-                    make_solver_instance_ready();
-                }
-                return Solver::SolutionExists;
+                m_winMoves.append(new_move);
             }
 
-        case FCS_STATE_SUSPEND_PROCESS:
-            return Solver::UnableToDetermineSolvability;
-
-        default:
             make_solver_instance_ready();
-            return Solver::NoSolutionExists;
+        }
+        return Solver::SolutionExists;
+    }
+
+    case FCS_STATE_SUSPEND_PROCESS:
+        return Solver::UnableToDetermineSolvability;
+
+    default:
+        make_solver_instance_ready();
+        return Solver::NoSolutionExists;
     }
 }
 
@@ -253,15 +237,14 @@ void FcSolveSolver::print_layout()
 #endif
 }
 
-void FcSolveSolver::unpack_cluster( unsigned int)
+void FcSolveSolver::unpack_cluster(unsigned int)
 {
     return;
 }
 
 void FcSolveSolver::make_solver_instance_ready()
 {
-    if (solver_instance && (solver_ret != FCS_STATE_NOT_BEGAN_YET))
-    {
+    if (solver_instance && (solver_ret != FCS_STATE_NOT_BEGAN_YET)) {
         freecell_solver_user_recycle(solver_instance);
         solver_ret = FCS_STATE_NOT_BEGAN_YET;
     }
@@ -269,10 +252,8 @@ void FcSolveSolver::make_solver_instance_ready()
 
 FcSolveSolver::~FcSolveSolver()
 {
-    if (solver_instance)
-    {
+    if (solver_instance) {
         freecell_solver_user_free(solver_instance);
         solver_instance = nullptr;
     }
 }
-
